@@ -1,2 +1,2 @@
 from .policy_store import opa_client
-from .opal_client import OpalClient
\ No newline at end of file
+from .client import OpalClient
\ No newline at end of file
